@@ -136,6 +136,7 @@ package Sidef::Optimizer {
                       to
                       downto
 
+                      pack
                       concat
                       prepend
 
@@ -236,6 +237,7 @@ package Sidef::Optimizer {
                       div
                       repeat
                       char
+                      slice
 
                       sprintf
                       sprintlnf
@@ -267,6 +269,15 @@ package Sidef::Optimizer {
                 )
             ),
 
+            # String.method(Number, Number)
+            (
+                map { [$_, [table(NUMBER), table(NUMBER)]] } methods(
+                    STRING, qw(
+                      slice
+                      )
+                )
+            ),
+
             # String.method(String, Number)
             (
                 map { [$_, [table(STRING), table(NUMBER)]] } methods(
@@ -799,7 +810,7 @@ package Sidef::Optimizer {
                       first
                       last
                       item
-                      ft
+                      slice
 
                       sum
                       prod
